@@ -3,7 +3,7 @@
 
 package Mesoderm::Command;
 {
-  $Mesoderm::Command::VERSION = '0.131260';
+  $Mesoderm::Command::VERSION = '0.140780';
 }
 use Moose;
 with 'MooseX::Getopt';
@@ -62,7 +62,7 @@ sub execute {
   my $schema_class   = $self->schema_class;
   my $scaffold_class = $self->scaffold_class;
 
-  Class::MOP::load_class($scaffold_class);
+  Class::Load::load_class($scaffold_class);
 
   my $sqlt = SQL::Translator->new(
     parser      => 'DBI',
